/*****
  file: board_config.c
  Description: Board specific procedures and macros
  date: February 12, 2004
  author: Emil Jovanov
***/  
  
#include <msp430x14x.h>
#include <string.h>
#include "board_config.h"
#include "serial.h"

/*** Long delay */
void delay(void)
{
  uint16 i;
  for (i = 65000; i > 0; i--);
  for (i = 65000; i > 0; i--);
}

/*** Short delay */
#define DELAY_COUNT 20000
void short_delay(void)
{
  uint16 i;
  for (i = DELAY_COUNT; i > 0; i--);
}

/*** Initialize clock system (MCLK, ACLK, SMCLK) */
void SetUpClocks(void)
{
  IFG2 = 0; IFG1 = 0;

  BCSCTL1 |= XTS; // enable XTAL1 as a high frequency crystal

  /*wait in loop until crystal stabilizes*/
  do {
    IFG1 &= ~OFIFG;
  } while (OFIFG & IFG1);

  /*Reset osc. fault flag again  */
  IFG1 &= ~OFIFG;
  
  /* Set MCLK same as LFXT1CLK, SMCLK=DCOCLK */
  BCSCTL2 = SELM_3;

}

/*** UART0 Initialization */
void UART_Initialize(void) {

#ifdef USE_UART0
  U0MCTL = 146;
  U0BR0  = 208;
  U0BR1  = 0;

  P3SEL |= BIT4+BIT5; // bits 4-5 are for special function UART0

  ME1 |= URXE0 + UTXE0; // UART module enable
  U0CTL = CHAR;
  U0TCTL = SSEL0;
  U0RCTL = 0;

#ifdef UART0_INT_DRIVEN
  uart0_rx_head = 0;
  uart0_rx_tail = 0;
  uart0_tx_head = 0;
  uart0_tx_tail = 0;
  uart0_flags = 0;
  IE1 |= UTXIE0 + URXIE0;  // enable TX and RX interrupts
#endif // UART0_INT_DRIVEN
#endif // USE_UART0

/*** UART1 Initialization */
#ifdef USE_UART1

  U0MCTL = 146;
  U0BR0  = 208;
  U0BR1  = 0;

  P3SEL |= 0xC0; // bits 6-7 are for special function UART1
  ME2 |= URXE1 + UTXE1; // UART module enable
  U1CTL = CHAR;
  U1TCTL = SSEL0;
  U1RCTL = 0;

#ifdef UART1_INT_DRIVEN
  uart1_rx_head = 0;
  uart1_rx_tail = 0;
  uart1_tx_head = 0;
  uart1_tx_tail = 0;
  uart1_flags = 0;
  IE2 |= UTXIE1 + URXIE1;  // enable TX and RX interrupts
#endif // UART1_INT_DRIVEN
#endif // USE_UART1

}
